/*
 * matrix_statistic.hpp
 *
 *  Created on: Dec 17, 2011
 *      Author: raoul
 */

#ifndef MATRIX_STATISTIC_HPP_
#define MATRIX_STATISTIC_HPP_

#include <list>
#include <sstream>
#include <sys/times.h>
#include <omp.h>
#include "utilities.hpp"

#define MATRIX_DO_STAT

class c_matrix_statistic
{
  nested_timer<> times;
  std::string inversion_method;
  std::string parallelism_state;
  double error_measure;
  int size;
  std::string generation_method;
  double difficulty;
  time_t seed;

  friend
  std::ostream & operator << (std::ostream & strm, const c_matrix_statistic & ms);

public:
  inline void
  start_timer()
  {
    times.start();
  }

  inline void
  stop_timer()
  {
    times.stop();
  }

  inline void
  reset_timer()
  {
    times.reset();
  }

  inline double
  get_time_measurement() const
  {
    return times.front().get_seconds();
  }

  inline void
  set_inversion_method(const std::string new_inversion_method)
  {
    inversion_method = new_inversion_method;
    times.reset();
  }

  inline void
  set_parallelism_state(const std::string new_parallelism_state)
  {
    parallelism_state = new_parallelism_state;
  }

  inline void
  set_error_measure(const double new_error_measure)
  {
    error_measure = new_error_measure;
  }

  inline void
  set_matrix_info(const int new_size, const char * new_generation_method,
      const double new_difficulty, const time_t new_seed)
  {
    size = new_size;
    generation_method = new_generation_method;
    difficulty = new_difficulty;
    seed = new_seed;
  }
};

std::ostream &
operator << (std::ostream & strm, const c_matrix_statistic & ms)
{
  strm << "@ ";
  // inversion method and time: real, user + system
  strm << "im " << ms.inversion_method << " " << ms.parallelism_state << " - ";
  // number of processors
  const char * ont = getenv("OMP_NUM_THREADS");
  if (ont)
	  strm << "ncpu " << ont << " ";
	else
    strm << "ncpu " << omp_get_num_procs() << " ";
  // matrix size
  strm << "size " << ms.size << " ";
  // random generation method and parameters
  strm << "rnd " << ms.generation_method << " " << ms.difficulty << " " << ms.seed << " ";
  // error and time
  strm << "err " << ms.error_measure << " ";
  strm << "itm " << ms.times.front().get_seconds() << " "
      << ms.times.get_seconds() << " ";
  strm << std::endl;
  return strm;
}

c_matrix_statistic m_stat;

#endif /* MATRIX_STATISTIC_HPP_ */







