/*
 * recursive.hpp
 *
 *  Created on: Dec 11, 2011
 *      Author: raoul
 */

#ifndef RECURSIVE_HPP_
#define RECURSIVE_HPP_

#include <list>

template <typename T1, typename T2>
class recursion
{
public:
  class callback
  {
    recursion & rec;

    friend class recursion;

    callback(recursion & r)
      : rec(r)
    {}

  public:
    inline void
    operator () (T1 t1, T2 t2)
    {
      rec(t1, t2);
    }
  };

  typedef void (* recursive_function_pointer) (T1, T2, callback);
  typedef void (& recursive_function_reference) (T1, T2, callback);
private:
  typedef std::list<recursive_function_pointer> function_container;
  typedef typename function_container::const_iterator function_iterator;

  function_container recursive_functions;
  function_iterator current_function;

public:
  recursion()
    : recursive_functions(),
      current_function(recursive_functions.begin())
  {}

  void
  add_function(recursive_function_reference fp)
  {
    recursive_functions.push_back(fp);
    current_function = recursive_functions.begin();
  }

  inline void
  operator () (T1 t1, T2 t2)
  {
    assert(current_function != recursive_functions.end());
    (*(current_function++))(t1, t2, callback(*this));
    --current_function;
  }

};


#endif /* RECURSIVE_HPP_ */












