#!/bin/bash

exec &> >(tee -a log)
declare -i stoptime="$(date '+%s') + 60 * 60 * 18"

set_num_active_cores ()
{
	# parameters: all/<num>
	
	local -i NumCores=32
	
	local -i i n
	local proclist="0"
	if [ "x$1" == "xall" ]; then
		n=$NumCores
	else
		n=$1
	fi
	for ((i=1; i<n; ++i)); do
		proclist="$proclist,$i"
	done
	
	export OMP_NUM_THREADS="$n"
	export KMP_AFFINITY="granularity=fine,proclist=[$proclist],explicit"
}

tests ()
{
round="round + 1"
echo "start of round $round"

set_num_active_cores all

./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 8)) 10" "mult" stat "invert N" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 8)) 10" "mult" stat "invert SN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 8)) 10" "mult" stat "invert SSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 8)) 10" "mult" stat "invert SSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 8)) 10" "mult" stat "invert SSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 8)) 10" "mult" stat "invert SSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 8)) 10" "mult" stat "invert SSSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 8)) 10" "mult" stat "invert SSSSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 8)) 10" "mult" stat "invert SSSSSSSSN" stat >>results-by-depth-turbo-off

./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 10)) 10" "mult" stat "invert N" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 10)) 10" "mult" stat "invert SN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 10)) 10" "mult" stat "invert SSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 10)) 10" "mult" stat "invert SSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 10)) 10" "mult" stat "invert SSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 10)) 10" "mult" stat "invert SSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 10)) 10" "mult" stat "invert SSSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 10)) 10" "mult" stat "invert SSSSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 10)) 10" "mult" stat "invert SSSSSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 10)) 10" "mult" stat "invert SSSSSSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 10)) 10" "mult" stat "invert SSSSSSSSSSN" stat >>results-by-depth-turbo-off

./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert N" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert SN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert SSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert SSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert SSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert SSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert SSSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert SSSSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert SSSSSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert SSSSSSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert SSSSSSSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert SSSSSSSSSSSN" stat >>results-by-depth-turbo-off
./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 12)) 10" "mult" stat "invert SSSSSSSSSSSSN" stat >>results-by-depth-turbo-off

#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert N" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSSN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSSSN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSSSSN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSSSSSN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSSSSSSN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSSSSSSSN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSSSSSSSSN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSSSSSSSSSN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSSSSSSSSSSN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSSSSSSSSSSSN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSSSSSSSSSSSSN" stat >>results-by-depth-turbo-off
#./matrix_invert.bin "rand_gen eigen_loguni $((2 ** 14)) 10" "mult" stat "invert SSSSSSSSSSSSSSN" stat >>results-by-depth-turbo-off



set_num_active_cores all
echo "round $round done"
}

echo "start of $0"
declare -i round=0
for (( i=0;i<30;i++ )); do
	tests
done








