//============================================================================
// Name        : matrix_invert.cpp
// Author      : Raoul Steffen
// Version     :
// Copyright   : 
// Description : Hello World in C, Ansi-style
//============================================================================

#include <stdio.h>
#include <stdlib.h>
#include <string>

#include "matrix_statistic.hpp"
#include "matrix.hpp"
#include "matrix_generator.hpp"

#ifndef PRECISION
  #define PRECISION 64
#endif

#if (PRECISION == 64)
  typedef matrix<double> matrix_type;
#elif (PRECISION == 32)
  typedef matrix<float> matrix_type;
#else
  #error // only 32 and 64 bit floating point known
#endif

typedef matrix_type::element_type element_type;
typedef matrix_generator<element_type> matrix_generator_type;

// plan:
// newton-iterations: log (n) + log log 52

void
simple_test()
{
  const int size = 32;

  // generate a matrix
  matrix_type A = matrix_generator_type::generate(matrix_generator_type::inverse_tridiagonal_ones(size), size);
  /*time_t seed = 0;
  matrix_type A = matrix_generator_type::generate(matrix_generator_type::normal_distribution(1, 2, seed), size);
  std::cout << "normal distribution, seed: " << seed << "\n"; // */
  //matrix_type A = matrix_generator_type::generate(matrix_generator_type::diagonal_ascending(), size);

  matrix_type Ai = A.invert(false, "N");
  //matrix_type Ai = A.invert(false, matrix_type::S_STRASSEN_NEWTON, 2);
  //matrix_type Ai = A.invert(false, matrix_type::LAPACK_SPD);

  // print Ai
  std::cout << "inverse:\n" << Ai << "\n";
  // print stats
  std::cout << m_stat;
  //puts(Ai.to_string().c_str());
}

//Read in Sparse Matrices from http://www.cise.ufl.edu/research/sparse/matrices/ to prove things in practice.
matrix_type sparse_read (std::string filename) {

  std::ifstream file(filename.data());     // open file
  std::string line;
  int lnr = 0;
  int rows, cols, ents;
  int r,c;
  double val;
  matrix_type M;

  while (file.good())          // loop while extraction from file is possible
  {
    std::getline (file, line);       // get character from file
    if (line.length() == 0) break;
    if (line[0] == '%') continue;
    std::istringstream fline(line);
    
    // Matrix Dimensions are in the first line
    if (lnr == 0){
      fline >> rows >> cols >> ents;
      if (rows != cols) std::cout << "Matrix not quadratic!!\n";
      M.set_size(rows);
      //M.set_symmetric(true);
      lnr = 1;
      continue;
    }
    
    //We should only be here if fline contains a matrix entry!
    fline >> r >> c >> val;
    M.elem(r-1, c-1) = val;
    //if (r != c) M.elem(c-1,r-1) = val;
    //was this correct for symmetric matrices anyway?
    
    lnr++;
    //std::cout << line << "\n";
  }
  if ((lnr-1) != ents) std::cout << "Matrix not completely loaded!!\n";
  file.close();

  return M;
}

void
parse_commands(int n_args, char * args[])
{
  #if PARALLEL
    #if (PRECISION == 32)
      m_stat.set_parallelism_state("si");
    #else
      m_stat.set_parallelism_state("p");
    #endif
  #elif EXPLOIT_SYMMETRIC_MULTIPLICATION
    m_stat.set_parallelism_state("s");
  #else
    m_stat.set_parallelism_state("sf");
  #endif

  std::string cl;
  matrix_type M, Mi;
  bool M_is_spd = false;

  //while (getline(std::cin, cl).good())
  for (int i = 1; i < n_args; ++i)
  {
    cl = args[i];
    /* possible commands:
     *   <""> - do nothing
     *   load X f [spd] - load X (in {M,Mi}) from filename f
     *   sparse_read X f [spd] - load X (in {M,Mi}) from filename f
     *   store X f - store X (in {M,Mi}) to filename f
     *   rand_gen ... - generate M randomly
     *     normal size [sigma [seed]] - with elements independently normal distributed
     *     eigen_uni size max_condition [seed] by eigenvalue decomposition
     *         with eigenvalues uniquely distributed in [1, max_condition)
     *     eigen_lognormal size sigma_condition [seed] - generate M randomly by eigenvalue decomposition
     *         with eigenvalues lognormal distributed
     *     eigen_uni_div_sqrt size max_condition [seed] - generate M randomly by eigenvalue decomposition
     *         with eigenvalues choosen as X/sqrt(maxcond)
     *     eigen_uni_div_d size max_condition d [seed] - generate M randomly by eigenvalue decomposition
     *         with eigenvalues choosen as X/d
     *     eigen_loguni size max_log_condition [seed] - generate M randomly by eigenvalue decomposition
     *         with eigenvalues choosen as 2^X
     *     eigen_uni_div_uni size max_condition [seed] - generate M randomly by eigenvalue decomposition
     *         with eigenvalues choosen as X/Y
     *         with X and Y independently uniquely distributed in [1, sqrt(max_condition))
     *   invert ... - invert M to Mi using ...
     *      available base inversion methods:
     *        L: call LAPACK inversion
     *        N: Newton inversion
     *        d: set the diagonal to 1/one_norm(M) as initially for Newton inversion
     *      available recursive inversion methods:
     *        n: one iteration of Newton inversion (to improve the approximation)
     *        S: Strassen inversion
     *      e.g.:
     *        SnSnSnSN - four levels of Strassen-inversion, each except the outermost with
     *            followed by Newton-stabilization, and Newton-inversion as base.
     *   stat - print statistics line
     *   mult - multiply M and M
     */
    std::istringstream cls(cl);

    std::string cmd;
    cls >> cmd;
    if (cmd == "load")
    {
      std::string x, f;
      cls >> x >> f;
      std::ifstream file;
      file.open(f.c_str(), std::ios::binary);
      if (x == "M")
        M.load(file);
      else if (x == "Mi")
        Mi.load(file);
      else
        std::cerr << "unknown matrix: \"" << x << "\"\n";
      file.close();
      M_is_spd = false;
      if (! cls.eof())
      {
      	std::string spd;
      	cls >> spd;
      	if (spd == "spd")
      		M_is_spd = true;
      	else
      		std::cerr << "unknown optional parameter to load: \"" << spd << "\"\n";
      }
      if (x == "M")
        m_stat.set_matrix_info(M.get_height(), "load", 0, 0);
    }
    else if (cmd == "sparse_read")
    {
      std::string x, f;
      cls >> x >> f;
      //std::ifstream file;
      //file.open(f.c_str(), std::ios::binary);
      if (x == "M")
        M = sparse_read(f);
      else if (x == "Mi")
        Mi = sparse_read(f);
      else
        std::cerr << "unknown matrix: \"" << x << "\"\n";
      //file.close();
      M_is_spd = false;
      if (! cls.eof())
      {
      	std::string spd;
      	cls >> spd;
      	if (spd == "spd")
      		M_is_spd = true;
      	else
      		std::cerr << "unknown optional parameter to load: \"" << spd << "\"\n";
      }
      if (x == "M")
        m_stat.set_matrix_info(M.get_height(), "sparse_read", 0, 0);
    }
    else if (cmd == "store")
    {
      std::string x, f;
      cls >> x >> f;
      std::ofstream file;
      file.open(f.c_str(), std::ios::trunc | std::ios::binary);
      if (x == "M")
        M.store(file);
      else if (x == "Mi")
        Mi.store(file);
      else
        std::cerr << "unknown matrix: \"" << x << "\"\n";
      file.close();
    }
    else if (cmd == "rand_gen")
    {
      std::string method;
      cls >> method;
      if (method == "normal")
      {
        matrix_type::size_type size;
        time_t seed;
        element_type sigma;
        cls >> size;
        if (! cls.eof())
          sigma = 1;
        else
          cls >> sigma;
        if (cls.eof())
          seed = 0;
        else
          cls >> seed;
        M = matrix_generator_type::generate(matrix_generator_type::normal_distribution(0, sigma, seed), size);
        M_is_spd = false;
        m_stat.set_matrix_info(size, "norm", sigma, seed);
      }
      else if (method == "eigen_uni")
      {
        matrix_type::size_type size;
        element_type max_cond;
        time_t seed;
        cls >> size >> max_cond;
        if (cls.eof())
          seed = 0;
        else
          cls >> seed;
        assert(max_cond > 1);
        M = matrix_generator_type::spd_by_eigendecomposition(
              size, boost::random::uniform_real_distribution<element_type>(1, max_cond), seed
            );
        M_is_spd = true;
        m_stat.set_matrix_info(size, "e_uni", max_cond, seed);
      }
      else if (method == "eigen_div_uni")
      {
        matrix_type::size_type size;
        element_type max_cond;
        time_t seed;
        cls >> size >> max_cond;
        if (cls.eof())
          seed = 0;
        else
          cls >> seed;
        assert(max_cond > 1);
        M = matrix_generator_type::spd_by_eigendecomposition(
              size, matrix_generator_type::dist_div_uni(max_cond), seed
            );
        M_is_spd = true;
        m_stat.set_matrix_info(size, "e_div_uni", max_cond, seed);
      }
      else if (method == "eigen_uni_div_sqrt")
      {
        matrix_type::size_type size;
        element_type max_cond;
        time_t seed;
        cls >> size >> max_cond;
        if (cls.eof())
          seed = 0;
        else
          cls >> seed;
        assert(max_cond > 1);
        M = matrix_generator_type::spd_by_eigendecomposition(
              size, matrix_generator_type::dist_uni_div(max_cond, sqrt(max_cond)), seed
            );
        M_is_spd = true;
        m_stat.set_matrix_info(size, "e_uni_ds", max_cond, seed);
      }
      else if (method == "eigen_loguni")
      {
        matrix_type::size_type size;
        element_type max_log_cond;
        time_t seed;
        cls >> size >> max_log_cond;
        if (cls.eof())
          seed = 0;
        else
          cls >> seed;
        assert(max_log_cond / 2 > 0);
        M = matrix_generator_type::spd_by_eigendecomposition(
              size, matrix_generator_type::dist_loguni(max_log_cond), seed
            );
        M_is_spd = true;
        m_stat.set_matrix_info(size, "e_loguni", max_log_cond, seed);
      }
      else if (method == "eigen_uni_div_d")
      {
        matrix_type::size_type size;
        element_type max_cond, d;
        time_t seed;
        cls >> size >> max_cond >> d;
        if (cls.eof())
          seed = 0;
        else
          cls >> seed;
        assert(max_cond > 1);
        M = matrix_generator_type::spd_by_eigendecomposition(
              size, matrix_generator_type::dist_uni_div(max_cond, d), seed
            );
        M_is_spd = true;
        m_stat.set_matrix_info(size, "e_uni_d", max_cond, seed);
      }
      else if (method == "eigen_lognormal")
      {
        matrix_type::size_type size;
        element_type sigma_cond;
        time_t seed;
        cls >> size >> sigma_cond;
        if (cls.eof())
          seed = 0;
        else
          cls >> seed;
        M = matrix_generator_type::spd_by_eigendecomposition(
              size, boost::random::lognormal_distribution<element_type> (0, sigma_cond), seed
            );
        M_is_spd = true;
        m_stat.set_matrix_info(size, "e_ln", sigma_cond, seed);
      }
      else if (method == "eigen_uni_div_uni")
      {
        matrix_type::size_type size;
        element_type max_cond;
        time_t seed;
        cls >> size >> max_cond;
        if (cls.eof())
          seed = 0;
        else
          cls >> seed;
        M = matrix_generator_type::spd_by_eigendecomposition(
              size, matrix_generator_type::dist_uni_div_uni(max_cond), seed
            );
        M_is_spd = true;
        m_stat.set_matrix_info(size, "e_udu", max_cond, seed);
      }
      else
        std::cerr << "unknown generator: \"" << method << "\"\n";
    }
    else if (cmd == "invert")
    {
      std::string method;
      cls >> method;

      m_stat.set_inversion_method(method);
      try
      {
        Mi = M.invert(M_is_spd, method);
        m_stat.set_error_measure((Mi * M).max_norm_diff_unity());
      }
      catch (matrix_type::unknown_inversion_method_error & e)
      {
        std::cerr << "unknown inversion method: '" << e.method << "' in \"" << method << "\"\n";
      }
      catch (matrix_type::singular_inversion_error & e)
      {
        std::cerr << "singular inversion error.\n";
        m_stat.set_error_measure(std::numeric_limits<double>::infinity());
        m_stat.reset_timer();
      }
      catch (matrix_type::bad_condition_inversion_error & e)
      {
        std::cerr << "bad condition inversion error.\n";
        m_stat.set_error_measure(std::numeric_limits<double>::infinity());
        m_stat.reset_timer();
      }
    }
    else if (cmd == "stat")
      std::cout << m_stat;
    else if (cmd == "mult")
    {
      m_stat.set_inversion_method("mult");
      matrix_type T(M.get_height());
      m_stat.start_timer();
      T.multiply(M, M);
      m_stat.stop_timer();
    }
    else if (cmd != "")
      std::cerr << "unknown command: \"" << cl << "\"\n";
  }
}

int
main(int n_args, char * args[])
{
  time_t now = time(0);
  std::cout << "this is matrix_invert, version of " << ctime(&now);

	//std::cout << "KMP_AFFINITY=" << getenv("KMP_AFFINITY") << "\n";
  //omp_set_nested(true);  // starts to many threads on Gordon
  //omp_set_dynamic(true);  // suspected to sometimes cause unpredicted behavior (entire program running single threaded)
  parse_commands(n_args, args);
  
  std::cout << "\n";
  return EXIT_SUCCESS;
}




